@@ -73,7 +73,7 @@
 #define yynerrs         constexpYYnerrs
 
 /* First part of user prologue.  */
-#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
 
 
 #include "cppvalue.h"
@@ -93,7 +93,7 @@ int constexpYYerror(yyscan_t yyscanner, const char *s)
 }
 
 
-#line 97 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 97 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -1181,192 +1181,192 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* start: constant_expression  */
-#line 75 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 75 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
        {
          struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
          /* dummy statement to silence a 'set but not used' compiler warning */ (void)yynerrs;
          yyextra->resultValue = yyvsp[0]; return 0;
        }
-#line 1191 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1191 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 3: /* constant_expression: logical_or_expression  */
-#line 83 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 83 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1197 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1197 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 4: /* constant_expression: logical_or_expression TOK_QUESTIONMARK logical_or_expression TOK_COLON logical_or_expression  */
-#line 87 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 87 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      {
-		       bool c = (yyvsp[-4].isInt() ? ((long)yyvsp[-4] != 0) : ((double)yyvsp[-4] != 0.0));
+		       bool c = (yyvsp[-4].type()==CPPValue::Type::Int ? ((long)yyvsp[-4] != 0) : ((double)yyvsp[-4] != 0.0));
 		       yyval = c ? yyvsp[-2] : yyvsp[0];
 	             }
-#line 1206 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1206 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 5: /* logical_or_expression: logical_and_expression  */
-#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1212 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1212 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 6: /* logical_or_expression: logical_or_expression TOK_OR logical_and_expression  */
-#line 96 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 96 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((long)yyvsp[-2] || (long)yyvsp[0]) );
 		       }
-#line 1220 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1220 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 7: /* logical_and_expression: inclusive_or_expression  */
-#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                         { yyval = yyvsp[0]; }
-#line 1226 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1226 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 8: /* logical_and_expression: logical_and_expression TOK_AND inclusive_or_expression  */
-#line 104 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 104 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                         {
 			  yyval = CPPValue( (long)((long)yyvsp[-2] && (long)yyvsp[0]) );
 			}
-#line 1234 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1234 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 9: /* inclusive_or_expression: exclusive_or_expression  */
-#line 110 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 110 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1240 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1240 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 10: /* inclusive_or_expression: inclusive_or_expression TOK_BITWISEOR exclusive_or_expression  */
-#line 113 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 113 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] | (long)yyvsp[0] );
 			 }
-#line 1248 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1248 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 11: /* exclusive_or_expression: and_expression  */
-#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 12: /* exclusive_or_expression: exclusive_or_expression TOK_BITWISEXOR and_expression  */
-#line 121 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 121 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] ^ (long)yyvsp[0] );
 			 }
-#line 1262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 13: /* and_expression: equality_expression  */
-#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                 { yyval = yyvsp[0]; }
-#line 1268 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1268 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 14: /* and_expression: and_expression TOK_AMPERSAND equality_expression  */
-#line 129 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 129 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                 {
 		  yyval = CPPValue( (long)yyvsp[-2] & (long)yyvsp[0] );
 		}
-#line 1276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 15: /* equality_expression: relational_expression  */
-#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1282 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1282 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 16: /* equality_expression: equality_expression TOK_EQUAL relational_expression  */
-#line 137 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 137 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      {
 		       yyval = CPPValue( (long)((double)yyvsp[-2] == (double)yyvsp[0]) );
 	             }
-#line 1290 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1290 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 17: /* equality_expression: equality_expression TOK_NOTEQUAL relational_expression  */
-#line 141 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 141 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      {
                        yyval = CPPValue( (long)((double)yyvsp[-2] != (double)yyvsp[0]) );
 		     }
-#line 1298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 18: /* relational_expression: shift_expression  */
-#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1304 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1304 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 19: /* relational_expression: relational_expression TOK_LESSTHAN shift_expression  */
-#line 149 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 149 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] < (double)yyvsp[0]) );
 		       }
-#line 1312 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1312 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 20: /* relational_expression: relational_expression TOK_GREATERTHAN shift_expression  */
-#line 153 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 153 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        {
                          yyval = CPPValue( (long)((double)yyvsp[-2] > (double)yyvsp[0]) );
 		       }
-#line 1320 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1320 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 21: /* relational_expression: relational_expression TOK_LESSTHANOREQUALTO shift_expression  */
-#line 158 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 158 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        {
 		         yyval = CPPValue( (long)((double)yyvsp[-2] <= (double)yyvsp[0]) );
 		       }
-#line 1328 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1328 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 22: /* relational_expression: relational_expression TOK_GREATERTHANOREQUALTO shift_expression  */
-#line 163 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 163 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] >= (double)yyvsp[0]) );
 		       }
-#line 1336 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1336 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 23: /* shift_expression: additive_expression  */
-#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1342 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1342 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 24: /* shift_expression: shift_expression TOK_SHIFTLEFT additive_expression  */
-#line 171 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 171 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] << (long)yyvsp[0] );
 		  }
-#line 1350 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1350 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 25: /* shift_expression: shift_expression TOK_SHIFTRIGHT additive_expression  */
-#line 175 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 175 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] >> (long)yyvsp[0] );
 		  }
-#line 1358 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1358 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 26: /* additive_expression: multiplicative_expression  */
-#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1364 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1364 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 27: /* additive_expression: additive_expression TOK_PLUS multiplicative_expression  */
-#line 183 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 183 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      {
-		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
+		       if (yyvsp[-2].type()!=CPPValue::Type::Int || yyvsp[0].type()!=CPPValue::Type::Int)
 		       {
 		         yyval = CPPValue( (double)yyvsp[-2] + (double)yyvsp[0] );
 		       }
@@ -1375,13 +1375,13 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] + (long)yyvsp[0] );
 		       }
 		     }
-#line 1379 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1379 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 28: /* additive_expression: additive_expression TOK_MINUS multiplicative_expression  */
-#line 194 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 194 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                      {
-		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
+		       if (yyvsp[-2].type()!=CPPValue::Type::Int || yyvsp[0].type()!=CPPValue::Type::Int)
 		       {
 		         yyval = CPPValue( (double)yyvsp[-2] - (double)yyvsp[0] );
 		       }
@@ -1390,19 +1390,19 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] - (long)yyvsp[0] );
 		       }
 		     }
-#line 1394 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1394 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 29: /* multiplicative_expression: unary_expression  */
-#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                            { yyval = yyvsp[0]; }
-#line 1400 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1400 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 30: /* multiplicative_expression: multiplicative_expression TOK_STAR unary_expression  */
-#line 209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                            {
-			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
+			     if (yyvsp[-2].type()!=CPPValue::Type::Int || yyvsp[0].type()!=CPPValue::Type::Int)
 			     {
 			       yyval = CPPValue( (double)yyvsp[-2] * (double)yyvsp[0] );
 			     }
@@ -1411,13 +1411,13 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] * (long)yyvsp[0] );
 			     }
 			   }
-#line 1415 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1415 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 31: /* multiplicative_expression: multiplicative_expression TOK_DIVIDE unary_expression  */
-#line 220 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 220 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                            {
-			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
+			     if (yyvsp[-2].type()!=CPPValue::Type::Int || yyvsp[0].type()!=CPPValue::Type::Int)
 			     {
 			       yyval = CPPValue( (double)yyvsp[-2] / (double)yyvsp[0] );
 			     }
@@ -1428,126 +1428,126 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] / value );
 			     }
 			   }
-#line 1432 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1432 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 32: /* multiplicative_expression: multiplicative_expression TOK_MOD unary_expression  */
-#line 233 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 233 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                            {
 			     long value = yyvsp[0];
 			     if (value==0) value=1;
 			     yyval = CPPValue( (long)yyvsp[-2] % value );
 			   }
-#line 1442 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1442 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 33: /* unary_expression: primary_expression  */
-#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1448 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1448 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 34: /* unary_expression: TOK_PLUS unary_expression  */
-#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   { yyval = yyvsp[-1]; }
-#line 1454 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1454 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 35: /* unary_expression: TOK_MINUS unary_expression  */
-#line 245 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 245 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   {
-		    if (yyvsp[0].isInt())
+		    if (yyvsp[0].type()==CPPValue::Type::Int)
                       yyval = CPPValue(-(long)yyvsp[0]);
                     else
 		      yyval = CPPValue(-(double)yyvsp[0]);
 		  }
-#line 1465 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1465 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 36: /* unary_expression: TOK_TILDE unary_expression  */
-#line 252 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 252 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   {
 		    yyval = CPPValue(~(long)yyvsp[0]);
 		  }
-#line 1473 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1473 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 37: /* unary_expression: TOK_NOT unary_expression  */
-#line 256 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 256 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                   {
 		    yyval = CPPValue((long)!(long)yyvsp[0]);
 		  }
-#line 1481 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1481 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 38: /* primary_expression: constant  */
-#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                     { yyval = yyvsp[0]; }
-#line 1487 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1487 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 39: /* primary_expression: TOK_LPAREN constant_expression TOK_RPAREN  */
-#line 264 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 264 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
                     { yyval = yyvsp[-1]; }
-#line 1493 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1493 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 40: /* constant: TOK_OCTALINT  */
-#line 268 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 268 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseOctal(yyextra->strToken);
 	  }
-#line 1502 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1502 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 41: /* constant: TOK_DECIMALINT  */
-#line 273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseDecimal(yyextra->strToken);
 	  }
-#line 1511 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1511 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 42: /* constant: TOK_HEXADECIMALINT  */
-#line 278 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 278 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseHexadecimal(yyextra->strToken);
 	  }
-#line 1520 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1520 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 43: /* constant: TOK_BINARYINT  */
-#line 283 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 283 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseBinary(yyextra->strToken);
 	  }
-#line 1529 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1529 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 44: /* constant: TOK_CHARACTER  */
-#line 288 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 288 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseCharacter(yyextra->strToken);
 	  }
-#line 1538 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1538 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 45: /* constant: TOK_FLOAT  */
-#line 293 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 293 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = CPPValue::parseFloat(yyextra->strToken);
 	  }
-#line 1547 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1547 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
 
-#line 1551 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/build/generated_src/ce_parse.cpp"
+#line 1551 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/build/generated_src/ce_parse.cpp"
 
       default: break;
     }
@@ -1740,5 +1740,5 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 299 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.15.0-1.x86_64/src/doxygen-1.15.0/src/constexp.y"
+#line 299 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.16.0-1.x86_64/src/doxygen-1.16.0/src/constexp.y"
 
